pub struct RollingMedian<T> { /* private fields */ }Expand description
A rolling median type.
This keeps track of a window of items and allows calculating the RollingMedian::median of them.
Example:
let mut rolling_median = RollingMedian::new(2);
rolling_median.push(1);
assert_eq!(rolling_median.median(), 1);
assert_eq!(rolling_median.window_len(), 1);
rolling_median.push(3);
assert_eq!(rolling_median.median(), 2);
assert_eq!(rolling_median.window_len(), 2);
rolling_median.push(5);
assert_eq!(rolling_median.median(), 4);
assert_eq!(rolling_median.window_len(), 2);Implementations
Sourceimpl<T> RollingMedian<T>
impl<T> RollingMedian<T>
Sourcepub fn new(target_window: usize) -> Self
pub fn new(target_window: usize) -> Self
Creates a new RollingMedian with a certain target window length.
target_window is the maximum amount of items to keep in the rolling window.
Sourcepub fn from_vec(vec: Vec<T>, target_window: usize) -> Self
pub fn from_vec(vec: Vec<T>, target_window: usize) -> Self
Creates a new RollingMedian from a Vec with a certain target window length.
target_window is the maximum amount of items to keep in the rolling window.
Panics
This function panics if vec.len() > target_window.
Sourcepub fn pop_front(&mut self)
pub fn pop_front(&mut self)
Pops the front of the window, i.e. the oldest item.
This is often not needed as RollingMedian::push will handle popping old values when they fall
out of the window.
Sourcepub fn push(&mut self, item: T)
pub fn push(&mut self, item: T)
Push an item to the back of the window.
This will pop the oldest item in the window if the target length has been exceeded.
Sourcepub fn append_front(&mut self, items: Vec<T>)
pub fn append_front(&mut self, items: Vec<T>)
Append some values to the front of the window.
These new values will be the oldest items in the window. The order of the inputted items will be
kept, i.e. the first item in the Vec will be the oldest item in the queue.
Sourcepub fn window_len(&self) -> usize
pub fn window_len(&self) -> usize
Returns the number of items currently in the RollingMedian.
Sourcepub fn median(&self) -> T
pub fn median(&self) -> T
Calculates the median of the values currently in the RollingMedian.
Sourcepub fn median_with_grace(&self, grace: usize) -> T
pub fn median_with_grace(&self, grace: usize) -> T
Calculates a median value with a set amount of grace values.
grace values are minimum values added to the back of the RollingMedian. The median is then
got as if these values had been added and replaced any values at the front, if the capacity is
reached.